/**
 * Copyright (C) 2011 Ovea <dev@ovea.com>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.ovea.resource.web;

import java.util.LinkedHashMap;
import java.util.Map;

final class VirtualResources {

    private final Map<String, VirtualResource> virtualResources = new LinkedHashMap<String, VirtualResource>();
    private boolean debug;

    VirtualResource addVirtualResource(String virtualPath) {
        if (!virtualPath.startsWith("/"))
            virtualPath = "/" + virtualPath;
        virtualPath = virtualPath.toLowerCase();
        if (virtualResources.containsKey(virtualPath))
            throw new IllegalStateException("Virtual path " + virtualPath + " already exist");
        VirtualResource virtualResource = new VirtualResource(virtualPath);
        virtualResource.setDebug(debug);
        virtualResources.put(virtualPath, virtualResource);
        return virtualResource;
    }

    public void setDebug(boolean debug) {
        this.debug = debug;
    }

    @Override
    public String toString() {
        return virtualResources.values().toString();
    }

    public void preload() {
        for (VirtualResource virtualResource : virtualResources.values()) {
            virtualResource.preload();
        }
    }

    public boolean has(String path) {
        return virtualResources.containsKey(path.toLowerCase());
    }

    public VirtualResource get(String path) {
        VirtualResource virtualResource = virtualResources.get(path.toLowerCase());
        if (virtualResource == null)
            throw new IllegalStateException("Unknown virtual resource: " + path);
        return virtualResource;
    }
}